==> gnome-sharp-2.16.0-i586-1gsb.tgz: install/doinst.sh <==
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gnome-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gnome-sharp.dll policy.2.4.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.art-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.art-sharp.dll policy.2.8.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gnome-vfs-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gnome-vfs-sharp.dll policy.2.8.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.vte-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.vte-sharp.dll policy.2.6.vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gconf-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gconf-sharp.dll policy.2.8.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gnome-sharp/2.16.0.0__35e10195dab3c99f/gnome-sharp.dll gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.rsvg-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.rsvg-sharp.dll policy.2.6.rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.vte-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.vte-sharp.dll policy.2.8.vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gconf-sharp/2.16.0.0__35e10195dab3c99f/gconf-sharp.dll gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gnome-vfs-sharp/2.16.0.0__35e10195dab3c99f/gnome-vfs-sharp.dll gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.art-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.art-sharp.dll policy.2.4.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gconf-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gconf-sharp.dll policy.2.4.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.art-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.art-sharp.dll policy.2.6.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.rsvg-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.rsvg-sharp.dll policy.2.4.rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gtkhtml-sharp/2.16.0.0__35e10195dab3c99f/gtkhtml-sharp.dll gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gconf-sharp-peditors/2.16.0.0__35e10195dab3c99f/gconf-sharp-peditors.dll gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gtkhtml-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gtkhtml-sharp.dll policy.2.8.gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gconf-sharp-peditors/0.0.0.0__35e10195dab3c99f/policy.2.6.gconf-sharp-peditors.dll policy.2.6.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gconf-sharp-peditors/0.0.0.0__35e10195dab3c99f/policy.2.8.gconf-sharp-peditors.dll policy.2.8.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.vte-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.vte-sharp.dll policy.2.4.vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.rsvg-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.rsvg-sharp.dll policy.2.8.rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gtkhtml-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gtkhtml-sharp.dll policy.2.6.gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gconf-sharp-peditors/0.0.0.0__35e10195dab3c99f/policy.2.4.gconf-sharp-peditors.dll policy.2.4.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/vte-sharp/2.16.0.0__35e10195dab3c99f/vte-sharp.dll vte-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gnome-vfs-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gnome-vfs-sharp.dll policy.2.6.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/art-sharp/2.16.0.0__35e10195dab3c99f/art-sharp.dll art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gconf-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gconf-sharp.dll policy.2.6.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/rsvg-sharp/2.16.0.0__35e10195dab3c99f/rsvg-sharp.dll rsvg-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gtkhtml-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gtkhtml-sharp.dll policy.2.4.gtkhtml-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gnome-vfs-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gnome-vfs-sharp.dll policy.2.4.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gnome-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gnome-sharp.dll policy.2.8.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gnome-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gnome-sharp.dll policy.2.6.gnome-sharp.dll )

==> gnome-sharp-2.20.1-i586-1gsb.tgz: install/doinst.sh <==
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/art-sharp/2.20.0.0__35e10195dab3c99f/art-sharp.dll art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.16.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.16.art-sharp/0.0.0.0__35e10195dab3c99f/policy.2.16.art-sharp.dll policy.2.16.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.16.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.16.gconf-sharp-peditors/0.0.0.0__35e10195dab3c99f/policy.2.16.gconf-sharp-peditors.dll policy.2.16.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.art-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.art-sharp.dll policy.2.6.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.16.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.16.gconf-sharp/0.0.0.0__35e10195dab3c99f/policy.2.16.gconf-sharp.dll policy.2.16.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gconf-sharp-peditors/0.0.0.0__35e10195dab3c99f/policy.2.8.gconf-sharp-peditors.dll policy.2.8.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gnome-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gnome-sharp.dll policy.2.6.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gnome-vfs-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gnome-vfs-sharp.dll policy.2.8.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gnome-vfs-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gnome-vfs-sharp.dll policy.2.6.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gconf-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gconf-sharp.dll policy.2.4.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gnome-vfs-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gnome-vfs-sharp.dll policy.2.4.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gconf-sharp-peditors/0.0.0.0__35e10195dab3c99f/policy.2.6.gconf-sharp-peditors.dll policy.2.6.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gnome-vfs-sharp/2.20.0.0__35e10195dab3c99f/gnome-vfs-sharp.dll gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gconf-sharp-peditors/0.0.0.0__35e10195dab3c99f/policy.2.4.gconf-sharp-peditors.dll policy.2.4.gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.art-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.art-sharp.dll policy.2.8.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.16.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.16.gnome-sharp/0.0.0.0__35e10195dab3c99f/policy.2.16.gnome-sharp.dll policy.2.16.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gconf-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gconf-sharp.dll policy.2.8.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gconf-sharp/2.20.0.0__35e10195dab3c99f/gconf-sharp.dll gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.gnome-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.gnome-sharp.dll policy.2.4.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gconf-sharp-peditors/2.20.0.0__35e10195dab3c99f/gconf-sharp-peditors.dll gconf-sharp-peditors.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.4.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.4.art-sharp/0.0.0.0__35e10195dab3c99f/policy.2.4.art-sharp.dll policy.2.4.art-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.8.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.8.gnome-sharp/0.0.0.0__35e10195dab3c99f/policy.2.8.gnome-sharp.dll policy.2.8.gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/gnome-sharp/2.20.0.0__35e10195dab3c99f/gnome-sharp.dll gnome-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.16.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.16.gnome-vfs-sharp/0.0.0.0__35e10195dab3c99f/policy.2.16.gnome-vfs-sharp.dll policy.2.16.gnome-vfs-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; rm -rf policy.2.6.gconf-sharp.dll )
( cd usr/lib/mono/gtk-sharp-2.0 ; ln -sf ../gac/policy.2.6.gconf-sharp/0.0.0.0__35e10195dab3c99f/policy.2.6.gconf-sharp.dll policy.2.6.gconf-sharp.dll )
